# frozen_string_literal: true

# Licensed to the Software Freedom Conservancy (SFC) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The SFC licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

# This file is automatically generated. Any changes will be lost!
module Selenium
  module DevTools
    module V85
      class ApplicationCache
        EVENTS = {
          application_cache_status_updated: 'applicationCacheStatusUpdated',
          network_state_updated: 'networkStateUpdated',
        }.freeze

        def initialize(devtools)
          @devtools = devtools
        end

        def on(event, &block)
          event = EVENTS[event] if event.is_a?(Symbol)
          @devtools.callbacks["ApplicationCache.#{event}"] << block
        end

        def enable
          @devtools.send_cmd('ApplicationCache.enable')
        end

        def get_application_cache_for_frame(frame_id:)
          @devtools.send_cmd('ApplicationCache.getApplicationCacheForFrame',
                             frameId: frame_id)
        end

        def get_frames_with_manifests
          @devtools.send_cmd('ApplicationCache.getFramesWithManifests')
        end

        def get_manifest_for_frame(frame_id:)
          @devtools.send_cmd('ApplicationCache.getManifestForFrame',
                             frameId: frame_id)
        end

      end # ApplicationCache
    end # V85
  end # DevTools
end # Selenium