# frozen_string_literal: true

# Licensed to the Software Freedom Conservancy (SFC) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The SFC licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

# This file is automatically generated. Any changes will be lost!
module Selenium
  module DevTools
    module V93
      class DOMStorage
        EVENTS = {
          dom_storage_item_added: 'domStorageItemAdded',
          dom_storage_item_removed: 'domStorageItemRemoved',
          dom_storage_item_updated: 'domStorageItemUpdated',
          dom_storage_items_cleared: 'domStorageItemsCleared',
        }.freeze

        def initialize(devtools)
          @devtools = devtools
        end

        def on(event, &block)
          event = EVENTS[event] if event.is_a?(Symbol)
          @devtools.callbacks["DOMStorage.#{event}"] << block
        end

        def clear(storage_id:)
          @devtools.send_cmd('DOMStorage.clear',
                             storageId: storage_id)
        end

        def disable
          @devtools.send_cmd('DOMStorage.disable')
        end

        def enable
          @devtools.send_cmd('DOMStorage.enable')
        end

        def get_dom_storage_items(storage_id:)
          @devtools.send_cmd('DOMStorage.getDOMStorageItems',
                             storageId: storage_id)
        end

        def remove_dom_storage_item(storage_id:, key:)
          @devtools.send_cmd('DOMStorage.removeDOMStorageItem',
                             storageId: storage_id,
                             key: key)
        end

        def set_dom_storage_item(storage_id:, key:, value:)
          @devtools.send_cmd('DOMStorage.setDOMStorageItem',
                             storageId: storage_id,
                             key: key,
                             value: value)
        end

      end # DOMStorage
    end # V93
  end # DevTools
end # Selenium