# frozen_string_literal: true

# Licensed to the Software Freedom Conservancy (SFC) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The SFC licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

# This file is automatically generated. Any changes will be lost!
module Selenium
  module DevTools
    module V93
      class Security
        EVENTS = {
          certificate_error: 'certificateError',
          visible_security_state_changed: 'visibleSecurityStateChanged',
          security_state_changed: 'securityStateChanged',
        }.freeze

        def initialize(devtools)
          @devtools = devtools
        end

        def on(event, &block)
          event = EVENTS[event] if event.is_a?(Symbol)
          @devtools.callbacks["Security.#{event}"] << block
        end

        def disable
          @devtools.send_cmd('Security.disable')
        end

        def enable
          @devtools.send_cmd('Security.enable')
        end

        def set_ignore_certificate_errors(ignore:)
          @devtools.send_cmd('Security.setIgnoreCertificateErrors',
                             ignore: ignore)
        end

        def handle_certificate_error(event_id:, action:)
          @devtools.send_cmd('Security.handleCertificateError',
                             eventId: event_id,
                             action: action)
        end

        def set_override_certificate_errors(override:)
          @devtools.send_cmd('Security.setOverrideCertificateErrors',
                             override: override)
        end

      end # Security
    end # V93
  end # DevTools
end # Selenium